@@ -238,7 +238,8 @@ impl Interpreter for Mathematica_original {
     fn execute(&mut self) -> Result<String, SniprunError> {
         //run th binary and get the std output (or stderr)
         let interpreter = Mathematica_original::get_interpreter_or(&self.data, "WolframKernel");
-        let output = Command::new(interpreter)
+        let output = Command::new(interpreter.split_whitespace().next().unwrap())
+            .args(interpreter.split_whitespace().skip(1))
             .arg("-noprompt")
             .arg("-script")
             .arg(&self.main_file_path)
