@@ -113,7 +113,8 @@ impl Interpreter for TypeScript_original {
     fn execute(&mut self) -> Result<String, SniprunError> {
         //run th binary and get the std output (or stderr)
         let interpreter = TypeScript_original::get_interpreter_or(&self.data, "ts-node");
-        let output = Command::new(interpreter)
+        let output = Command::new(interpreter.split_whitespace().next().unwrap())
+            .args(interpreter.split_whitespace().skip(1))
             .arg(&self.main_file_path)
             .output()
             .expect("Unable to start process");
