@@ -212,7 +212,7 @@ impl EventHandler {
     fn index_from_name(&mut self, name: &str, config: &[(Value, Value)]) -> Option<usize> {
         for (i, kv) in config.iter().enumerate() {
             if name == kv.0.as_str().unwrap() {
-                info!("looped on key {}", kv.0.as_str().unwrap());
+                // info!("looped on key {}", kv.0.as_str().unwrap());
                 return Some(i);
             }
         }
